from palp.spider.spider_local import LocalSpider
from palp.spider.spider_distributive import DistributiveSpider
